==> payara-embedded-all-5.201-sources.jar: com/sun/enterprise/connectors/work/WorkManagerProxy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010, 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.connectors.work;


import javax.resource.spi.work.*;
import java.io.*;

/**
 * Proxy for WorkManager.<br>
 * This implementation is Serializable(Externalizable) such that RAR implementation
 * can use it safely in Serialization mandated scenarios<br>
 *
 * @author Jagadish Ramu
 */
public class WorkManagerProxy implements WorkManager, Externalizable {

    private transient WorkManager wm;
    private String moduleName;

    public WorkManagerProxy(WorkManager wm, String moduleName){
        this.wm = wm;
        this.moduleName = moduleName;
    }

    public WorkManagerProxy(){
    }

    /**
     * @see javax.resource.spi.work.WorkManager
     */
    public void doWork(Work work) throws WorkException {
        wm.doWork(work);
    }

    /**
     * @see javax.resource.spi.work.WorkManager
     */
    public void doWork(Work work, long startTimeout, ExecutionContext executionContext,
                       WorkListener workListener) throws WorkException {
        wm.doWork(work, startTimeout, executionContext, workListener);
    }

    /**
     * @see javax.resource.spi.work.WorkManager
     */
    public long startWork(Work work) throws WorkException {
        return wm.startWork(work);
    }

    /**
     * @see javax.resource.spi.work.WorkManager
     */
    public long startWork(Work work, long startTimeout, ExecutionContext executionContext,
                          WorkListener workListener) throws WorkException {
        return wm.startWork(work, startTimeout, executionContext, workListener);
    }

    /**
     * @see javax.resource.spi.work.WorkManager
     */
    public void scheduleWork(Work work) throws WorkException {
        wm.scheduleWork(work);
    }
    /**
     * @see javax.resource.spi.work.WorkManager
     */
    public void scheduleWork(Work work, long startTimeout, ExecutionContext executionContext,
                             WorkListener workListener) throws WorkException {
        wm.scheduleWork(work, startTimeout, executionContext, workListener);
    }

    /**
     * @see java.io.Externalizable
     */
    public void writeExternal(ObjectOutput out) throws IOException {
        out.writeUTF(moduleName);
    }

    /**
     * @see java.io.Externalizable
     */
    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        moduleName = in.readUTF();
        wm = WorkManagerFactoryImpl.retrieveWorkManager(moduleName);
    }

    public boolean equals(Object o){
        boolean equal = false;
        if(o instanceof WorkManagerProxy){
            WorkManagerProxy wmp = (WorkManagerProxy)o;
            equal = wmp.wm.equals(wm);
        }
        return equal;
    }

    public int hashCode(){
        return wm.hashCode();
    }
}

==> payara-embedded-all-6.2024.5-sources.jar: com/sun/enterprise/connectors/work/WorkManagerProxy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010, 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.connectors.work;


import jakarta.resource.spi.work.*;
import java.io.*;

/**
 * Proxy for WorkManager.<br>
 * This implementation is Serializable(Externalizable) such that RAR implementation
 * can use it safely in Serialization mandated scenarios<br>
 *
 * @author Jagadish Ramu
 */
public class WorkManagerProxy implements WorkManager, Externalizable {

    private transient WorkManager wm;
    private String moduleName;

    public WorkManagerProxy(WorkManager wm, String moduleName){
        this.wm = wm;
        this.moduleName = moduleName;
    }

    public WorkManagerProxy(){
    }

    /**
     * @see jakarta.resource.spi.work.WorkManager
     */
    public void doWork(Work work) throws WorkException {
        wm.doWork(work);
    }

    /**
     * @see jakarta.resource.spi.work.WorkManager
     */
    public void doWork(Work work, long startTimeout, ExecutionContext executionContext,
                       WorkListener workListener) throws WorkException {
        wm.doWork(work, startTimeout, executionContext, workListener);
    }

    /**
     * @see jakarta.resource.spi.work.WorkManager
     */
    public long startWork(Work work) throws WorkException {
        return wm.startWork(work);
    }

    /**
     * @see jakarta.resource.spi.work.WorkManager
     */
    public long startWork(Work work, long startTimeout, ExecutionContext executionContext,
                          WorkListener workListener) throws WorkException {
        return wm.startWork(work, startTimeout, executionContext, workListener);
    }

    /**
     * @see jakarta.resource.spi.work.WorkManager
     */
    public void scheduleWork(Work work) throws WorkException {
        wm.scheduleWork(work);
    }
    /**
     * @see jakarta.resource.spi.work.WorkManager
     */
    public void scheduleWork(Work work, long startTimeout, ExecutionContext executionContext,
                             WorkListener workListener) throws WorkException {
        wm.scheduleWork(work, startTimeout, executionContext, workListener);
    }

    /**
     * @see java.io.Externalizable
     */
    public void writeExternal(ObjectOutput out) throws IOException {
        out.writeUTF(moduleName);
    }

    /**
     * @see java.io.Externalizable
     */
    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        moduleName = in.readUTF();
        wm = WorkManagerFactoryImpl.retrieveWorkManager(moduleName);
    }

    public boolean equals(Object o){
        boolean equal = false;
        if(o instanceof WorkManagerProxy){
            WorkManagerProxy wmp = (WorkManagerProxy)o;
            equal = wmp.wm.equals(wm);
        }
        return equal;
    }

    public int hashCode(){
        return wm.hashCode();
    }
}
